@@ -6,7 +6,7 @@ from aws_cdk import (
 
 ##
 ## CodeBuild
-def createCodeBuildAction(self, codebuild_action_name, codebuild_input_artifact, codebuild_role):
+def createCodeBuildAction(self, codebuild_action_name, codebuild_input_artifact, codebuild_role, codebuild_env_variables=None):
     """
     Creates a CodeBuild Action.
  
@@ -25,7 +25,12 @@ def createCodeBuildAction(self, codebuild_action_name, codebuild_input_artifact,
             environment=codebuild.BuildEnvironment(
                 privileged=True
             ), 
+            environment_variables=codebuild_env_variables
+            
         ),
         input=codebuild_input_artifact,
     )
-    return codebuild_build_action
\ No newline at end of file
+    return codebuild_build_action
+
+def createCodeBuildEnvironmentVariable(self, env_var_value):
+    return codebuild.BuildEnvironmentVariable(value=env_var_value)
\ No newline at end of file
